@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -373,7 +373,7 @@ public abstract class KeyPairGenerator extends KeyPairGeneratorSpi {
      * supported by this KeyPairGenerator object.
      */
     public void initialize(int keysize) {
-        initialize(keysize, JCAUtil.getSecureRandom());
+        initialize(keysize, JCAUtil.getDefSecureRandom());
     }
 
     /**
@@ -433,7 +433,7 @@ public abstract class KeyPairGenerator extends KeyPairGeneratorSpi {
      */
     public void initialize(AlgorithmParameterSpec params)
             throws InvalidAlgorithmParameterException {
-        initialize(params, JCAUtil.getSecureRandom());
+        initialize(params, JCAUtil.getDefSecureRandom());
     }
 
     /**
